@@ -38,7 +38,7 @@
 #include <string.h>
 
 /**
- * SECTION: gapplication
+ * SECTION:gapplication
  * @title: GApplication
  * @short_description: Core application class
  *
@@ -64,6 +64,22 @@
  * For details on valid application identifiers, see
  * g_application_id_is_valid().
  *
+ * The application identifier is claimed by the application as a
+ * well-known bus name on the user's session bus.  This means that the
+ * uniqueness of your application is scoped to the current session.  It
+ * also means that your application may provide additional services
+ * (through registration of other object paths) at that bus name.
+ *
+ * The registration of these object paths should be done with the shared
+ * GDBus session bus.  Note that due to the internal architecture of
+ * GDBus, method calls can be dispatched at any time (even if a main
+ * loop is not running).  For this reason, you must ensure that any
+ * object paths that you wish to register are registered before
+ * #GApplication attempts to acquire the bus name of your application
+ * (which happens in g_application_register()).  Unfortunately, this
+ * means that you can not use g_application_get_is_remote() to decide if
+ * you want to register object paths.
+ *
  * GApplication provides convenient life cycle management by maintaining
  * a <firstterm>use count</firstterm> for the primary application instance.
  * The use count can be changed using g_application_hold() and
@@ -170,7 +186,8 @@ g_application_real_activate (GApplication *application)
 {
   if (!g_signal_has_handler_pending (application,
                                      g_application_signals[SIGNAL_ACTIVATE],
-                                     0, TRUE))
+                                     0, TRUE) &&
+      G_APPLICATION_GET_CLASS (application)->activate == g_application_real_activate)
     {
       static gboolean warned;
 
@@ -192,7 +209,8 @@ g_application_real_open (GApplication  *application,
 {
   if (!g_signal_has_handler_pending (application,
                                      g_application_signals[SIGNAL_OPEN],
-                                     0, TRUE))
+                                     0, TRUE) &&
+      G_APPLICATION_GET_CLASS (application)->open == g_application_real_open)
     {
       static gboolean warned;
 
@@ -357,7 +375,7 @@ g_application_set_property (GObject      *object,
 /**
  * g_application_set_action_group:
  * @application: a #GApplication
- * @action_group: a #GActionGroup, or %NULL
+ * @action_group: (allow-none): a #GActionGroup, or %NULL
  *
  * Sets or unsets the group of actions associated with the application.
  *
@@ -545,7 +563,7 @@ g_application_class_init (GApplicationClass *class)
   /**
    * GApplication::open:
    * @application: the application
-   * @files: an array of #GFile objects
+   * @files: (array length=n_files) (element-type GFile): an array of #GFiles
    * @n_files: the length of @files
    * @hint: a hint provided by the calling instance
    *
@@ -902,7 +920,14 @@ g_application_get_is_remote (GApplication *application)
  *
  * This is the point at which the application discovers if it is the
  * primary instance or merely acting as a remote for an already-existing
- * primary instance.
+ * primary instance.  This is implemented by attempting to acquire the
+ * application identifier as a uniue bus name on the session bus using
+ * GDBus.
+ *
+ * Due to the internal architecture of GDBus, method calls can be
+ * dispatched at any time (even if a main loop is not running).  For
+ * this reason, you must ensure that any object paths that you wish to
+ * register are registered before calling this function.
  *
  * If the application has already been registered then %TRUE is
  * returned with no work performed.
@@ -1047,7 +1072,7 @@ g_application_activate (GApplication *application)
 /**
  * g_application_open:
  * @application: a #GApplication
- * @files: an array of #GFiles to open
+ * @files: (array length=n_files): an array of #GFiles to open
  * @n_files: the length of the @files array
  * @hint: a hint (or ""), but never %NULL
  *
@@ -1094,7 +1119,7 @@ g_application_open (GApplication  *application,
  * g_application_run:
  * @application: a #GApplication
  * @argc: the argc from main()
- * @argv: the argv from main()
+ * @argv: (array length=argc): the argv from main()
  * @returns: the exit status
  *
  * Runs the application.
