@@ -32,10 +32,14 @@
 
 #include <string.h>  /* memset */
 
-#include "glib.h"
+#include "ghash.h"
+
+#include "gatomic.h"
+#include "gtestutils.h"
+
 
 /**
- * SECTION: hash_tables
+ * SECTION:hash_tables
  * @title: Hash Tables
  * @short_description: associations between keys and values so that
  *                     given a key the value can be found quickly
